==> gschedwicons-0.1.0.tar.gz: gschedwicons-0.1.0/src/find_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
     
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.
     
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/* find_cb.h -- GUI functions for the find job window */

#ifndef _FIND_CB_H
#define _FIND_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_find OF((GtkWidget *w));
extern void find_select_clicked OF((GtkButton *button));
extern void find_close_clicked OF((GtkButton *button));
extern void find_entry_activate OF((GtkEntry *entry));
extern void find_button_clicked OF((GtkButton *button));
extern gboolean find_delete_event OF((GtkWidget *widget));
extern void dialog_find_set_workload_date OF((	GtkWidget *dialog_find,
						int workload_date));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* find_cb.h */

/*-----------------============== End Of File ==============-----------------*/

==> gschedwicons-0.1.2.tar.gz: gschedwicons-0.1.2/src/find_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* find_cb.h -- GUI functions for the find job window */

#ifndef _FIND_CB_H
#define _FIND_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_find OF((GtkWidget *w));
extern void find_select_clicked OF((GtkButton *button));
extern void find_close_clicked OF((GtkButton *button));
extern void find_entry_activate OF((GtkEntry *entry));
extern void find_button_clicked OF((GtkButton *button));
extern gboolean find_delete_event OF((GtkWidget *widget));
extern void dialog_find_set_workload_date OF((	GtkWidget *dialog_find,
						int workload_date));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* find_cb.h */

/*-----------------============== End Of File ==============-----------------*/
